package dev.thinhha.tunnel_client.config;

import dev.thinhha.tunnel_client.entity.RouteConfig;
import dev.thinhha.tunnel_client.repository.RouteConfigRepository;
import dev.thinhha.tunnel_client.service.HeaderManipulationService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.CommandLineRunner;
import org.springframework.stereotype.Component;

@Component
@RequiredArgsConstructor
@Slf4j
public class DataInitializer implements CommandLineRunner {
    
    private final RouteConfigRepository routeConfigRepository;
    private final HeaderManipulationService headerManipulationService;
    private final TunnelConfig tunnelConfig;
    
    @Override
    public void run(String... args) throws Exception {
        // Load initial routes from configuration into database
        if (tunnelConfig.getTarget().getRoutes() != null) {
            tunnelConfig.getTarget().getRoutes().forEach((pathPattern, targetUrl) -> {
                if (!routeConfigRepository.existsByPathPattern(pathPattern)) {
                    RouteConfig route = new RouteConfig();
                    route.setPathPattern(pathPattern);
                    route.setTargetUrl(targetUrl);
                    route.setPriority(pathPattern.length()); // Longer paths get higher priority
                    route.setDescription("Auto-imported from configuration");
                    route.setEnabled(true);
                    
                    routeConfigRepository.save(route);
                    log.info("Imported route: {} -> {}", pathPattern, targetUrl);
                }
            });
        }
        
        // Add default CORS headers for API paths if not already configured
        if (headerManipulationService.getAllHeaderRules().isEmpty()) {
            log.info("Initializing default CORS headers...");
            headerManipulationService.addCorsHeaders(
                "/api",
                "*",
                "GET, POST, PUT, DELETE, OPTIONS, PATCH",
                "Origin, Content-Type, Accept, Authorization, X-Requested-With"
            );
            log.info("Default CORS headers added for /api paths");
        }
    }
}