package dev.thinhha.tunnel_client.config;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.http.converter.ByteArrayHttpMessageConverter;
import org.springframework.http.converter.StringHttpMessageConverter;
import org.springframework.http.converter.json.MappingJackson2HttpMessageConverter;
import org.springframework.web.client.RestTemplate;

import java.nio.charset.StandardCharsets;
import java.util.Arrays;

@Configuration
public class WebSocketConfig {
    
    @Bean
    public RestTemplate restTemplate() {
        RestTemplate restTemplate = new RestTemplate();
        
        // Configure message converters to handle different content types properly
        StringHttpMessageConverter stringConverter = new StringHttpMessageConverter(StandardCharsets.UTF_8);
        stringConverter.setWriteAcceptCharset(false);
        
        ByteArrayHttpMessageConverter byteArrayConverter = new ByteArrayHttpMessageConverter();
        MappingJackson2HttpMessageConverter jsonConverter = new MappingJackson2HttpMessageConverter();
        
        restTemplate.setMessageConverters(Arrays.asList(
            byteArrayConverter,  // Handle binary data
            stringConverter,     // Handle text data
            jsonConverter        // Handle JSON data
        ));
        
        // Configure error handler to not throw exceptions for HTTP error status codes
        restTemplate.setErrorHandler(new NoOpResponseErrorHandler());
        
        return restTemplate;
    }
}