package dev.thinhha.tunnel_client.controller;

import dev.thinhha.tunnel_client.entity.HeaderRule;
import dev.thinhha.tunnel_client.service.HeaderManipulationService;
import lombok.RequiredArgsConstructor;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.UUID;

@RestController
@RequestMapping("/api/header-rules")
@RequiredArgsConstructor
public class HeaderRuleController {
    
    private final HeaderManipulationService headerManipulationService;
    
    @GetMapping
    public List<HeaderRule> getAllHeaderRules() {
        return headerManipulationService.getAllHeaderRules();
    }
    
    @PostMapping
    public ResponseEntity<HeaderRule> addHeaderRule(@RequestBody HeaderRuleRequest request) {
        HeaderRule rule = headerManipulationService.addHeaderRule(
            request.getPathPattern(),
            request.getHeaderName(),
            request.getHeaderValue(),
            request.getRuleType(),
            request.getPriority(),
            request.getDescription()
        );
        return ResponseEntity.ok(rule);
    }
    
    @PostMapping("/cors")
    public ResponseEntity<String> addCorsHeaders(@RequestBody CorsRequest request) {
        headerManipulationService.addCorsHeaders(
            request.getPathPattern(),
            request.getAllowedOrigins(),
            request.getAllowedMethods(),
            request.getAllowedHeaders()
        );
        return ResponseEntity.ok("CORS headers added successfully");
    }
    
    @DeleteMapping
    public ResponseEntity<Void> removeHeaderRule(@RequestParam String pathPattern, @RequestParam String headerName) {
        headerManipulationService.removeHeaderRule(pathPattern, headerName);
        return ResponseEntity.ok().build();
    }
    
    public static class HeaderRuleRequest {
        private String pathPattern;
        private String headerName;
        private String headerValue;
        private HeaderRule.HeaderRuleType ruleType;
        private Integer priority;
        private String description;
        
        // Getters and setters
        public String getPathPattern() { return pathPattern; }
        public void setPathPattern(String pathPattern) { this.pathPattern = pathPattern; }
        
        public String getHeaderName() { return headerName; }
        public void setHeaderName(String headerName) { this.headerName = headerName; }
        
        public String getHeaderValue() { return headerValue; }
        public void setHeaderValue(String headerValue) { this.headerValue = headerValue; }
        
        public HeaderRule.HeaderRuleType getRuleType() { return ruleType; }
        public void setRuleType(HeaderRule.HeaderRuleType ruleType) { this.ruleType = ruleType; }
        
        public Integer getPriority() { return priority; }
        public void setPriority(Integer priority) { this.priority = priority; }
        
        public String getDescription() { return description; }
        public void setDescription(String description) { this.description = description; }
    }
    
    public static class CorsRequest {
        private String pathPattern;
        private String allowedOrigins = "*";
        private String allowedMethods = "GET, POST, PUT, DELETE, OPTIONS";
        private String allowedHeaders = "Origin, Content-Type, Accept, Authorization";
        
        // Getters and setters
        public String getPathPattern() { return pathPattern; }
        public void setPathPattern(String pathPattern) { this.pathPattern = pathPattern; }
        
        public String getAllowedOrigins() { return allowedOrigins; }
        public void setAllowedOrigins(String allowedOrigins) { this.allowedOrigins = allowedOrigins; }
        
        public String getAllowedMethods() { return allowedMethods; }
        public void setAllowedMethods(String allowedMethods) { this.allowedMethods = allowedMethods; }
        
        public String getAllowedHeaders() { return allowedHeaders; }
        public void setAllowedHeaders(String allowedHeaders) { this.allowedHeaders = allowedHeaders; }
    }
}