package dev.thinhha.tunnel_client.controller;

import dev.thinhha.tunnel_client.entity.RouteConfig;
import dev.thinhha.tunnel_client.service.RouteResolver;
import lombok.RequiredArgsConstructor;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/api/routes")
@RequiredArgsConstructor
public class RouteController {
    
    private final RouteResolver routeResolver;
    
    @GetMapping
    public List<RouteConfig> getAllRoutes() {
        return routeResolver.getAllRoutes();
    }
    
    @PostMapping
    public ResponseEntity<RouteConfig> addRoute(@RequestBody RouteRequest request) {
        RouteConfig route = routeResolver.addRoute(
            request.getPathPattern(),
            request.getTargetUrl(),
            request.getPriority(),
            request.getDescription()
        );
        return ResponseEntity.ok(route);
    }
    
    @DeleteMapping("/{pathPattern}")
    public ResponseEntity<Void> removeRoute(@PathVariable String pathPattern) {
        routeResolver.removeRoute(pathPattern);
        return ResponseEntity.ok().build();
    }
    
    @GetMapping("/resolve/{path}")
    public ResponseEntity<String> resolveRoute(@PathVariable String path) {
        String targetUrl = routeResolver.resolveTargetUrl("/" + path);
        return ResponseEntity.ok(targetUrl);
    }
    
    public static class RouteRequest {
        private String pathPattern;
        private String targetUrl;
        private Integer priority;
        private String description;
        
        public String getPathPattern() { return pathPattern; }
        public void setPathPattern(String pathPattern) { this.pathPattern = pathPattern; }
        
        public String getTargetUrl() { return targetUrl; }
        public void setTargetUrl(String targetUrl) { this.targetUrl = targetUrl; }
        
        public Integer getPriority() { return priority; }
        public void setPriority(Integer priority) { this.priority = priority; }
        
        public String getDescription() { return description; }
        public void setDescription(String description) { this.description = description; }
    }
}